@@ -87,15 +87,51 @@ class Headframe(Procedure):
 class Side(Enum):
     """Side of animal"""
 
-    LEFT = "left"
-    RIGHT = "right"
+    LEFT = "Left"
+    RIGHT = "Right"
+
+
+class VirusPrepType(Enum):
+    """Type of virus preparation"""
+
+    CRUDE = "Crude"
+    PURIFIED = "Purified"
+
+
+class InjectionMaterial(BaseModel):
+    """Description of injection material"""
+
+    name: str = Field(..., title="Name")
+    material_id: Optional[str] = Field(None, title="Material ID")
+    full_genome_name: Optional[str] = Field(
+        None,
+        title="Full genome name",
+        description="Full genome for virus construct",
+    )
+    plasmid_name: Optional[str] = Field(
+        None,
+        title="Plasmid name",
+        description="Short name used to reference the plasmid",
+    )
+    genome_copy: Optional[float] = Field(None, title="Genome copy")
+    titer: Optional[float] = Field(None, title="Titer (gc/mL", units="gc/mL")
+    prep_lot_number: Optional[str] = Field(
+        None, title="Preparation lot number"
+    )
+    prep_date: Optional[date] = Field(
+        None,
+        title="Preparation lot date",
+        description="Date this prep lot was titered",
+    )
+    prep_type: Optional[VirusPrepType] = Field(None, title="Viral prep type")
 
 
 class Injection(Procedure):
     """Description of an injection procedure"""
 
-    injection_virus: str = Field(..., title="Injection virus")
-    injection_virus_id: Optional[str] = Field(None, title="Injection virus ID")
+    injection_materials: List[InjectionMaterial] = Field(
+        None, title="Injection material", unique_items=True
+    )
     injection_duration: time = Field(..., title="Injection duration")
 
 
@@ -152,6 +188,24 @@ class IontophoresisInjection(BrainInjection):
     alternating_current: str = Field(..., title="Alternating current")
 
 
+class IntraCerebellarVentricleInjection(BrainInjection):
+    """Description of an interacerebellar ventricle injection"""
+
+    injection_type: str = Field("ICV", title="Injection type", const=True)
+    injection_volume: float = Field(
+        ..., title="Injection volume (nL)", units="nL"
+    )
+
+
+class IntraCisternalMagnaInjection(BrainInjection):
+    """Description of an interacisternal magna injection"""
+
+    injection_type: str = Field("ICM", title="Injection type", const=True)
+    injection_volume: float = Field(
+        ..., title="Injection volume (nL)", units="nL"
+    )
+
+
 class MriScanSequence(Enum):
     """MRI scan sequence"""
 
